@@ -27,6 +27,7 @@
 
 #include <KLocalizedString>
 #include <KRunner/RunnerManager>
+#include <KRun>
 
 RunnerMatchesModel::RunnerMatchesModel(const QString &runnerId, const QString &name,
     Plasma::RunnerManager *manager, QObject *parent)
@@ -60,6 +61,17 @@ QVariant RunnerMatchesModel::data(const QModelIndex &index, int role) const
         if (match.runner()->id() == "services") {
             return match.data().toString();
         }
+    } else if (role == Kicker::UrlRole) {
+        const QString &runnerId = match.runner()->id();
+        if (runnerId == QLatin1String("baloosearch")) {
+            return QUrl(match.data().toString());
+        } else if (runnerId == QLatin1String("recentdocuments")
+                   || runnerId == QLatin1String("services")) {
+            KService::Ptr service = KService::serviceByStorageId(match.data().toString());
+            if (service) {
+                return QUrl::fromLocalFile(service->entryPath());
+            }
+        }
     } else if (role == Kicker::HasActionListRole) {
         // Hack to expose the protected Plasma::AbstractRunner::actions() method.
         class MyRunner : public Plasma::AbstractRunner
@@ -72,7 +84,7 @@ QVariant RunnerMatchesModel::data(const QModelIndex &index, int role) const
 
         Q_ASSERT(runner);
 
-        return !runner->actions().isEmpty();
+        return match.runner()->id() == QLatin1String("services") || !runner->actions().isEmpty();
     } else if (role == Kicker::ActionListRole) {
         QVariantList actionList;
 
@@ -84,6 +96,30 @@ QVariant RunnerMatchesModel::data(const QModelIndex &index, int role) const
             actionList << item;
         }
 
+        if (!actionList.isEmpty()) {
+            actionList << Kicker::createSeparatorActionItem();
+        }
+
+        KService::Ptr service = KService::serviceByStorageId(match.data().toString());
+        if (service) {
+            const QVariantList &jumpListActions = Kicker::jumpListActions(service);
+            if (!jumpListActions.isEmpty()) {
+                actionList << jumpListActions << Kicker::createSeparatorActionItem();
+            }
+
+            QObject *appletInterface = static_cast<RunnerModel *>(parent())->appletInterface();
+
+            const QVariantList &addLauncherActions = Kicker::createAddLauncherActionList(appletInterface, service);
+            if (!addLauncherActions.isEmpty()) {
+                actionList << addLauncherActions << Kicker::createSeparatorActionItem();
+            }
+
+            const QVariantList &recentDocuments = Kicker::recentDocumentActions(service);
+            if (!recentDocuments.isEmpty()) {
+                actionList << recentDocuments << Kicker::createSeparatorActionItem();
+            }
+        }
+
         return actionList;
     }
 
@@ -107,6 +143,16 @@ bool RunnerMatchesModel::trigger(int row, const QString &actionId, const QVarian
         return false;
     }
 
+    QObject *appletInterface = static_cast<RunnerModel *>(parent())->appletInterface();
+
+    KService::Ptr service = KService::serviceByStorageId(match.data().toString());
+
+    if (Kicker::handleAddLauncherAction(actionId, appletInterface, service)) {
+        return true;
+    } else if (actionId == QLatin1String("_kicker_jumpListAction")) {
+        return KRun::run(argument.toString(), {}, nullptr, service ? service->name() : QString(), service ? service->icon() : QString());
+    }
+
     if (!actionId.isEmpty()) {
         QObject *obj = argument.value<QObject *>();
 
