@@ -41,9 +41,8 @@
 #include <KColorScheme>
 #include <KMessageBox>
 #include <KPluginFactory>
-#include <kio/netaccess.h>
-#include <kio/deletejob.h>
-#include <kio/jobuidelegate.h>
+#include <KJobUiDelegate>
+#include <KIO/DeleteJob>
 #include <KNewStuff3/KNS3/DownloadDialog>
 #include <KNewStuff3/KNS3/UploadDialog>
 
@@ -638,6 +637,7 @@ void KColorCm::updateColorSchemes()
     m_colorSchemes.append(KColorScheme(QPalette::Active, KColorScheme::Button, m_config));
     m_colorSchemes.append(KColorScheme(QPalette::Active, KColorScheme::Selection, m_config));
     m_colorSchemes.append(KColorScheme(QPalette::Active, KColorScheme::Tooltip, m_config));
+    m_colorSchemes.append(KColorScheme(QPalette::Active, KColorScheme::Complementary, m_config));
 
     m_wmColors.load(m_config);
 }
